==> deku-prop-types-0.2.1.tgz: package/lib/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var checkerFactory = function checkerFactory(name, validator) {
  return {
    get name() {
      return name;
    },
    get isRequired() {
      this.required = true;
      return this;
    },
    validate: function validate(prop, key) {
      if (this.required && prop === undefined) {
        return new Error(key + ' is required');
      }

      if (prop !== undefined) {
        if (typeof validator === 'string' && (typeof prop === 'undefined' ? 'undefined' : _typeof(prop)) !== validator) {
          return new TypeError(key + ' should be of type `' + name + '`');
        }

        if (typeof validator === 'function') {
          return validator(prop, key);
        }
      }

      return null;
    }
  };
};

module.exports.propTypes = {
  get any() {
    return checkerFactory('any', function () {
      return null;
    });
  },
  get array() {
    return checkerFactory('array', function (prop, key) {
      if (!Array.isArray(prop)) {
        return new TypeError(key + ' should be of type `array`');
      }
      return null;
    });
  },
  get arrayOf() {
    return function (validator) {
      return checkerFactory('arrayOf', function (prop, key) {
        var anyErrors = prop.some(function (p) {
          return validator.validate(p) instanceof Error;
        });
        if (anyErrors) {
          return new TypeError(key + ' does not consist of the correct type');
        }

        return null;
      });
    };
  },
  get bool() {
    return checkerFactory('bool', 'boolean');
  },
  get func() {
    return checkerFactory('func', 'function');
  },
  get instanceOf() {
    return function (constructor) {
      return checkerFactory('instanceOf', function (prop, key) {
        if (!(prop instanceof constructor)) {
          return new TypeError(key + ' is not an instance of `' + constructor.name + '`');
        }

        return null;
      });
    };
  },
  get number() {
    return checkerFactory('number', 'number');
  },
  get object() {
    return checkerFactory('object', 'object');
  },
  get objectOf() {
    return function (validator) {
      return checkerFactory('objectOf', function (prop, key) {
        var anyErrors = Object.keys(prop).some(function (p) {
          return validator.validate(prop[p]) instanceof Error;
        });

        if (anyErrors) {
          return new TypeError(key + ' does not consist of all properties with `' + validator.name + '` values');
        }

        return null;
      });
    };
  },
  get oneOf() {
    return function (allowedValues) {
      return checkerFactory('oneOf', function (prop, key) {
        var isAllowed = allowedValues.some(function (value) {
          return value === prop;
        });
        if (!isAllowed) {
          return new TypeError(key + ' is not one of the allowed values');
        }

        return null;
      });
    };
  },
  get oneOfType() {
    return function (allowedTypes) {
      return checkerFactory('oneOfType', function (prop, key) {
        var isAllowed = !allowedTypes.every(function (type) {
          return type.validate(prop) instanceof Error;
        });
        if (!isAllowed) {
          return new TypeError(key + ' is not one of the allowed types');
        }

        return null;
      });
    };
  },
  get shape() {
    return function (propsObj) {
      return checkerFactory('shape', function (prop, key) {
        var anyErrors = Object.keys(propsObj).some(function (validator) {
          return propsObj[validator].validate(prop[validator]) instanceof Error;
        });

        if (anyErrors) {
          return new TypeError(key + ' does not have the correct value types');
        }

        return null;
      });
    };
  },
  get string() {
    return checkerFactory('string', 'string');
  }
};

var validate = function validate(propTypes, props) {
  Object.keys(propTypes).forEach(function (key) {
    var result = undefined;
    if (typeof propTypes[key] === 'function') {
      result = propTypes[key](props, key);
    } else {
      result = propTypes[key].validate(props[key], key);
    }

    if (result instanceof Error) {
      throw result;
    }

    return null;
  });
};

module.exports.validate = function (component) {
  /* eslint-disable no-process-env */
  if (process.env.NODE_ENV === 'production') {
    return component;
  }

  if (typeof component === 'function') {
    return function (model) {
      validate(component.propTypes, model.props);
      return component(model);
    };
  }

  // create render function that validates and calls original render fn
  var transformedComponent = {
    render: function render(model) {
      validate(component.propTypes, model.props);
      return component.render(model);
    }
  };
  // copy original component's properties
  Object.keys(component).forEach(function (key) {
    if (key !== 'render') {
      transformedComponent[key] = component[key];
    }
  });
  return transformedComponent;
};

==> deku-prop-types-0.2.2.tgz: package/lib/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var checkerFactory = function checkerFactory(name, validator) {
  return {
    get isRequired() {
      this.required = true;
      return this;
    },
    validate: function validate(prop, key) {
      if (this.required && prop === undefined) {
        return new Error(key + ' is required');
      }

      if (prop !== undefined) {
        if (typeof validator === 'string' && (typeof prop === 'undefined' ? 'undefined' : _typeof(prop)) !== validator) {
          return new TypeError(key + ' should be of type `' + name + '`');
        }

        if (typeof validator === 'function') {
          return validator(prop, key);
        }
      }

      return null;
    }
  };
};

module.exports.propTypes = {
  get any() {
    return checkerFactory('any', function () {
      return null;
    });
  },
  get array() {
    return checkerFactory('array', function (prop, key) {
      if (!Array.isArray(prop)) {
        return new TypeError(key + ' should be of type `array`');
      }
      return null;
    });
  },
  get arrayOf() {
    return function (validator) {
      return checkerFactory('arrayOf', function (prop, key) {
        if (!Array.isArray(prop)) {
          return new TypeError(key + ' is not an `Array`');
        }
        var anyErrors = prop.some(function (p) {
          return validator.validate(p) instanceof Error;
        });
        if (anyErrors) {
          return new TypeError(key + ' does not consist of the correct type');
        }

        return null;
      });
    };
  },
  get bool() {
    return checkerFactory('bool', 'boolean');
  },
  get func() {
    return checkerFactory('func', 'function');
  },
  get instanceOf() {
    return function (constructor) {
      return checkerFactory('instanceOf', function (prop, key) {
        if (!(prop instanceof constructor)) {
          return new TypeError(key + ' is not an instance of `' + constructor.name + '`');
        }

        return null;
      });
    };
  },
  get number() {
    return checkerFactory('number', 'number');
  },
  get object() {
    return checkerFactory('object', 'object');
  },
  get objectOf() {
    return function (validator) {
      return checkerFactory('objectOf', function (prop, key) {
        var propKeys = Object.keys(prop);

        for (var i = 0; i < propKeys.length; i++) {
          var validatorResult = validator.validate(prop[propKeys[i]], key + '.' + propKeys[i]);

          if (validatorResult instanceof Error) {
            return validatorResult;
          }
        }

        return null;
      });
    };
  },
  get oneOf() {
    return function (allowedValues) {
      return checkerFactory('oneOf', function (prop, key) {
        var isAllowed = allowedValues.some(function (value) {
          return value === prop;
        });
        if (!isAllowed) {
          return new TypeError(key + ' is not one of the allowed values');
        }

        return null;
      });
    };
  },
  get oneOfType() {
    return function (allowedTypes) {
      return checkerFactory('oneOfType', function (prop, key) {
        var isAllowed = !allowedTypes.every(function (type) {
          return type.validate(prop) instanceof Error;
        });
        if (!isAllowed) {
          return new TypeError(key + ' is not one of the allowed types');
        }

        return null;
      });
    };
  },
  get shape() {
    return function (propsObj) {
      return checkerFactory('shape', function (prop, key) {
        var validators = Object.keys(propsObj);

        for (var i = 0; i < validators.length; i++) {
          var validatorResult = propsObj[validators[i]].validate(prop[validators[i]], key + '.' + validators[i]);

          if (validatorResult instanceof Error) {
            return validatorResult;
          }
        }

        return null;
      });
    };
  },
  get string() {
    return checkerFactory('string', 'string');
  }
};

var validate = function validate(propTypes, props) {
  Object.keys(propTypes).forEach(function (key) {
    var result = undefined;
    if (typeof propTypes[key] === 'function') {
      result = propTypes[key](props, key);
    } else {
      result = propTypes[key].validate(props[key], key);
    }

    if (result instanceof Error) {
      throw result;
    }

    return null;
  });
};

module.exports.validate = function (component) {
  /* eslint-disable no-process-env */
  if (process.env.NODE_ENV === 'production') {
    return component;
  }

  if (typeof component === 'function') {
    return function (model) {
      validate(component.propTypes, model.props);
      return component(model);
    };
  }

  // create render function that validates and calls original render fn
  var transformedComponent = {
    render: function render(model) {
      validate(component.propTypes, model.props);
      return component.render(model);
    }
  };
  // copy original component's properties
  Object.keys(component).forEach(function (key) {
    if (key !== 'render') {
      transformedComponent[key] = component[key];
    }
  });
  return transformedComponent;
};
